@@ -1,15 +1,22 @@
-#![cfg_attr(feature = "external_doc", feature(external_doc))]
-#![cfg_attr(feature = "external_doc", doc(include = "../README.md"))]
+// Wrap this in two cfg_attrs so that it continues to parse pre-1.54.0.
+// See https://github.com/rust-lang/rust/issues/82768
+#![cfg_attr(feature = "external_doc", cfg_attr(all(), doc = include_str!("../README.md")))]
 #![cfg_attr(
     not(feature = "external_doc"),
-    doc = "See https://docs.rs/num_enum for more info about this crate."
+    doc = "See <https://docs.rs/num_enum> for more info about this crate."
 )]
 #![cfg_attr(not(feature = "std"), no_std)]
 
-pub use ::num_enum_derive::{IntoPrimitive, TryFromPrimitive, UnsafeFromPrimitive};
+pub use ::num_enum_derive::{FromPrimitive, IntoPrimitive, TryFromPrimitive, UnsafeFromPrimitive};
 
 use ::core::fmt;
 
+pub trait FromPrimitive: Sized {
+    type Primitive: Copy + Eq;
+
+    fn from_primitive(number: Self::Primitive) -> Self;
+}
+
 pub trait TryFromPrimitive: Sized {
     type Primitive: Copy + Eq + fmt::Debug;
 
