@@ -1,6 +1,12 @@
-use std::convert::TryFrom;
+use ::std::convert::TryFrom;
 
-use num_enum::{FromPrimitive, TryFromPrimitive};
+use ::num_enum::{FromPrimitive, TryFromPrimitive};
+
+// Guard against https://github.com/illicitonion/num_enum/issues/27
+mod alloc {}
+mod core {}
+mod num_enum {}
+mod std {}
 
 #[test]
 fn has_from_primitive_number() {
